/* 	
	----------------------------------------------------

	Dusty
	
	The OME UI Elements Library
	Domenico Gaudioso
	
	----------------------------------------------------
 */



	
/* 	
	----------------------------------------------------

	Table Of Contents:
	
	
	:: Buttons - Generic (.btn)
		:: Button - Blue (.btn.blue)
		:: Button - Silver (.btn.silver)

	:: Tags

	:: Context Box - Generic
		:: Context Box - Dark
	
	
	----------------------------------------------------
 */
	








/*
	------------------------------------------------
	:: Buttons - Generic
	------------------------------------------------
*/

button {
	display:inline-block;
	cursor:pointer;
}

button::-moz-focus-inner {
    border: 0;
    padding: 0;
}


		/* Singular Buttons */
		.btn{
			-webkit-border-radius:3px;
			-moz-border-radius:3px;
			border-radius:3px;
			display:inline-block;
			padding:0;
		}
		
		
	
			.btn span{
				font-weight:bold;
				display:block;
				-webkit-border-radius:inherit;
				-moz-border-radius:inherit;
				border-radius:inherit;
			}
			
			
		
		
		/* Menu Buttons */

		.menu_btns {
			overflow:hidden;
		}
			
			.menu_btns li {
				float:left;
			}
			
			.menu_btns li:first-child {
				border-left:none !important;
				 -webkit-border-bottom-left-radius:4px;
				 -moz-border-radius-bottomleft:4px;
				 border-bottom-left-radius:4px;				 
				 -webkit-border-top-left-radius:4px; /* Saf3+, Chrome */
				 -moz-border-radius-topleft:4px; /* FF1+ */
				 border-top-left-radius:4px; /* Opera 10.5, IE 9 */ 
			}
			
			
			.menu_btns li:last-child {
				border-right:none !important;
				-webkit-border-bottom-right-radius:4px; /* Saf3+, Chrome */
				-moz-border-radius-bottomright:4px; /* FF1+ */
				border-bottom-right-radius:4px; /* Opera 10.5, IE 9 */
				-webkit-border-top-right-radius:4px;
				-moz-border-radius-topright:4px;
				border-top-right-radius:4px; 
				
			}
			
		
				.menu_btns li a {
					display:block;
					text-indent: -9999px;
					-webkit-transition:none !important;		
					   -moz-transition:none !important;
					     -o-transition:none !important;
					        transition:none !important; 
				}
				
	
	
	
	/* Specific Buttons Images*/  
	
    .btn_view {background: url('../../webgateway/img/icon_view.png') center center no-repeat;}
    .btn_folder {background: url('../../webgateway/img/icon_folder.png') center center no-repeat;}
	.btn_download {background: url('../../webgateway/img/icon_download.png') center center no-repeat;}
	.btn_url {background: url('../../webgateway/img/icon_external_link.svg') center center no-repeat; background-size: 14px 14px; width: 26px; height: 26px;}
    .btn_filetype {background: url('../../webgateway/img/icon_filetype.png') center center no-repeat;}
    .btn_view_error {background: url('../../webgateway/img/icon_view_error.png') center center no-repeat;}
    .btn_info {background: url('../../webgateway/img/icon_info.png')center center no-repeat;}
    .btn_add {background: url('../../webgateway/img/icon_add.png')center center no-repeat;}
    .btn_edit {background: url('../../webgateway/img/icon_edit.png')center center no-repeat;}
    .btn_script_dark {background: url('../../webgateway/img/icon_script_dark.png')center center no-repeat;}
    .btn_figscripts {background: url('../../webgateway/img/icon_figure_scripts.png') center center no-repeat;}
    .btn_fspath {background: url('../../webgateway/img/icon_fs_path.png')center center no-repeat;}
    .btn_hierarchy {background: url('../../webgateway/img/iconmonstr-sitemap-6-icon-16.png') center center no-repeat;}
    .btn_link {background: url('../../webgateway/img/icon_link.png')center center no-repeat;}

	.btn_fspath, .btn_link, .btn_add, .btn_hierarchy {
	    float:right;
	    position: relative;
	    margin-left: 5px;
	}
	
	
	
	a.btn_add span, a.btn_edit span, button.btn_add span, button.btn_edit span {
		width:20px;
		height:18px;
		display:block;
	}
	.btn_fspath span, .btn_hierarchy span {
	    width:25px;
	    height:18px;
	    display:block;
	}
	.btn_link span {
	    width:29px;
	    height:18px;
	    display:block;
	}
	.toolbar input.btn_script_dark {
		margin:0;
		padding:0;
		width:22px;
		height:20px;
		display:block;
		cursor:pointer;
	}
	.toolbar input.btn_script_dark.button-disabled:hover {
		/* Overrides the default "button-disabled" class semantics for the
		 * script button.  They are focused towards use in the toolbar.
		 */
		background: url('../../webgateway/img/icon_script_dark.png')center center no-repeat;
	}
    
    .toolbar_dropdown .btn span {
        width:20px;
        height:18px;
        display:block;
    }
    
    #metadata_general .btn_download {
        background: url(../../webgateway/img/icon_download2.png) center center no-repeat;
    }

    #metadata_general .btn_openwith {
        background: url(../image/icon_openwith_toolbar.png) center center no-repeat;
    }
    
    .toolbar_dropdown {
        float:right;
        margin-left: 5px;
        position: relative;
    }
    .toolbar_dropdown .dropdown {
        right: -35px;
        left: auto;
    }
    .toolbar_dropdown .dropdown:before {
        left: 68%;
    }
    .toolbar_dropdown ul a {
        background: none;
        font-size: 80%;
    }

    /* Dropdown to the right of the button */
    .toolbar_dropdown .dropdown_right {
        right: auto;
    }
    .toolbar_dropdown .dropdown_right:before {
        left: 2%;
    }

	/* Channel edit form */
    #channel_names_edit button {
        height: 20px;
    }
    .confirmButtons {
        display: none;
    }
	#channel_names_edit.in_progress button[type='submit'] {
		/* Show a spinner while saving channels */
		background: url('../../webgateway/img/spinner.gif') center center no-repeat;
		color: transparent;
	}

	#channel_names_edit.in_progress button[type='reset'] {
		/* Don't show Cancel button during Save as it does nothing */
		visibility: hidden;
	}

    .channel_rename_spinner {
        height: 12px;
        vertical-align: middle;
        /* hide initially */
        display: none;
    }
        

/*
	------------------------------------------------
	:: Button - Blue
	------------------------------------------------
*/

		
		.btn.blue {
			background-color:hsl(210,40%,60%);
			border:solid 1px hsl(210,30%,50%);
			border-bottom:solid 1px hsl(210,30%,40%);
		}
		
		.btn.blue:hover {
			background-color:hsl(210,40%,65%);
		}
		
		.btn.blue:active {
			position:relative;
			top:1px;
		}
		
		
			.btn.blue span {
				color: hsl(210,50%,20%);
				text-shadow:0 1px 0 rgba(255,255,255,.3);
				-webkit-box-shadow:inset 0 1px 0 rgba(255,255,255,0.1); /* Saf3.0+, Chrome */
				   -moz-box-shadow:inset 0 1px 0 rgba(255,255,255,0.1); /* FF3.5+ */
				        box-shadow:inset 0 1px 0 rgba(255,255,255,0.1); /* Opera 10.5, IE 9.0 */
				background-image: -webkit-gradient(linear, left bottom, left top, from(rgba(255,255,255,0)), to(rgba(255,255,255,.2)));
				
				background-image:-moz-linear-gradient(top, rgba(255,255,255,.2) 0%, rgba(255,255,255,0) 100%); /* FF3.6+ */
				background-image:-webkit-gradient(linear, left top, left bottom, color-stop(0%,rgba(255,255,255,.2)), color-stop(100%,rgba(255,255,255,0))); /* Chrome,Safari4+ */
				background-image:-webkit-linear-gradient(top, rgba(255,255,255,.2) 0%,rgba(255,255,255,0) 100%); /* Chrome10+,Safari5.1+ */
				background-image:-o-linear-gradient(top, rgba(255,255,255,.2) 0%,rgba(255,255,255,0) 100%); /* Opera11.10+ */
				background-image:-ms-linear-gradient(top, rgba(255,255,255,.2) 0%,rgba(255,255,255,0) 100%); /* IE10+ */
				
				background:linear-gradient(top, rgba(255,255,255,.2) 0%,rgba(255,255,255,0) 100%); /* W3C */ 
				
			}
			
			.btn.blue:active span, .btn.blue:focus span{
				background-image: -webkit-gradient(linear, left bottom, left top, from(rgba(255,255,255,.2)), to(rgba(255,255,255,0)));
				
				background-image:-moz-linear-gradient(top, rgba(255,255,255,0) 0%, rgba(255,255,255,.2) 100%); /* FF3.6+ */
				background-image:-webkit-gradient(linear, left top, left bottom, color-stop(0%,rgba(255,255,255,0)), color-stop(100%,rgba(255,255,255,.2))); /* Chrome,Safari4+ */
				background-image:-webkit-linear-gradient(top, rgba(255,255,255,0) 0%,rgba(255,255,255,.2) 100%); /* Chrome10+,Safari5.1+ */
				background-image:-o-linear-gradient(top, rgba(255,255,255,0) 0%,rgba(255,255,255,.2) 100%); /* Opera11.10+ */
				background-image:-ms-linear-gradient(top, rgba(255,255,255,0) 0%,rgba(255,255,255,.2) 100%); /* IE10+ */
				
				background:linear-gradient(top, rgba(255,255,255,0) 0%,rgba(255,255,255,.2) 100%); /* W3C */ 
			}
			
			




/*
	------------------------------------------------
	:: Button - Silver
	------------------------------------------------
*/

		
		
			
			
		/* State */	
		
			
			
		.menu_btns.silver {
			border-top:solid 1px rgba(0,0,0,.1);
			border-left:solid 1px rgba(0,0,0,.2);
			border-right:solid 1px rgba(0,0,0,.2);
			border-bottom:solid 1px rgba(0,0,0,.2);

			-webkit-border-radius:4px; /* Saf3+, Chrome */
			   -moz-border-radius:4px; /* FF1+ */
			        border-radius:4px; /* Opera 10.5, IE 9 */ 

			-webkit-box-shadow:0 1px 0 white;
			-webkit-box-shadow: 0 1px 0 rgba(255,255,255,1); /* Saf3.0+, Chrome */
			   -moz-box-shadow: 0 1px 0 rgba(255,255,255,1); /* FF3.5+ */
			        box-shadow: 0 1px 0 rgba(255,255,255,1); /* Opera 10.5, IE 9.0 */

		}
		
		
		
			.btn.silver, .menu_btns.silver li {
				background-color:hsl(210,8%,90%);
				color:hsl(210,5%,30%);
				text-shadow: 0 1px 0 white;
			}
		
			.btn.silver {
				border:solid 1px hsl(210,8%,65%);
				-webkit-box-shadow:0 1px 0 rgba(255,255,255,.5);
				-webkit-box-shadow: 0 1px 0 rgba(255,255,255,0.5); /* Saf3.0+, Chrome */
				   -moz-box-shadow: 0 1px 0 rgba(255,255,255,0.5); /* FF3.5+ */
				        box-shadow: 0 1px 0 rgba(255,255,255,0.5); /* Opera 10.5, IE 9.0 */
			}
			
			.menu_btns.silver li {
				border-left: solid 1px rgba(255,255,255,.3);
				border-right:solid 1px rgba(0,0,0,.1);
				-webkit-transition: none !important;
				-webkit-transition:none !important  ;		
				   -moz-transition:none !important  ;
				     -o-transition:none !important  ;
				        transition:none !important  ; 
			}
			
			
				.btn.silver span, .menu_btns.silver a {
					color:hsl(210,5%,30%);
					line-height:1.3em;
					display:inline-block;
					cursor:pointer;
					
					-webkit-box-shadow:inset 0 1px 0 rgba(255,255,255,0.4); /* Saf3.0+, Chrome */
					   -moz-box-shadow:inset 0 1px 0 rgba(255,255,255,0.4); /* FF3.5+ */
					        box-shadow:inset 0 1px 0 rgba(255,255,255,0.4); /* Opera 10.5, IE 9.0 */
					background-image: -webkit-gradient(linear, left bottom, left top, from(rgba(255,255,255,0)), to(rgba(255,255,255,.3)));
					
					background-image:-moz-linear-gradient(top, rgba(255,255,255,.3) 0%, rgba(255,255,255,0) 100%); /* FF3.6+ */
					background-image:-webkit-gradient(linear, left top, left bottom, color-stop(0%,rgba(255,255,255,.3)), color-stop(100%,rgba(255,255,255,0))); /* Chrome,Safari4+ */
					background-image:-webkit-linear-gradient(top, rgba(255,255,255,.3) 0%,rgba(255,255,255,0) 100%); /* Chrome10+,Safari5.1+ */
					background-image:-o-linear-gradient(top, rgba(255,255,255,.3) 0%,rgba(255,255,255,0) 100%); /* Opera11.10+ */
					background-image:-ms-linear-gradient(top, rgba(255,255,255,.3) 0%,rgba(255,255,255,0) 100%); /* IE10+ */
					
					background:linear-gradient(top, rgba(255,255,255,.3) 0%,rgba(255,255,255,0) 100%); /* W3C */ 
					
				}

				
		
		
		
		
		/* Hover */	
		
		.btn.silver:hover, .menu_btns.silver li:hover {
			background-color:hsl(210,8%,94%);
			
		}
		
		
		
		/* Active, Focus */
		
		.btn.silver:active, .btn.silver:focus, .menu_btns.silver li:active, .menu_btns.silver li:focus {
			background-color:hsl(210,8%,70%);
			-webkit-transition:none;		
			   -moz-transition:none;
			     -o-transition:none;
			        transition:none; 
			border:solid 1px hsl(210,8%,55%);
			border-top:solid 1px hsl(210,8%,48%);
		}
		
		
		.menu_btns.silver li:active, .menu_btns.silver li:focus {
			border-left: solid 1px rgba(0,0,0,.15);
			border-right:solid 1px transparent;
			border-top:none;
			border-bottom:none;
		}
		
		
			.btn.silver:active span, .btn.silver:focus span{
				-webkit-box-shadow: inset 0 1px 3px hsla(210,8%,50%,.8);
				
				-webkit-box-shadow:inset 0 1px 3px hsla(210,8%,50%,0.8); /* Saf3.0+, Chrome */
				   -moz-box-shadow:inset 0 1px 3px hsla(210,8%,50%,0.8); /* FF3.5+ */
				        box-shadow:inset 0 1px 3px hsla(210,8%,50%,0.8); /* Opera 10.5, IE 9.0 */
				
				background-image:-webkit-gradient(linear, left bottom, left top, from(rgba(255,255,255,.2)), to(rgba(255,255,255,0)));
				
				background-image:-moz-linear-gradient(top, rgba(255,255,255,0) 0%, rgba(255,255,255,.2) 100%); /* FF3.6+ */
				background-image:-webkit-gradient(linear, left top, left bottom, color-stop(0%,rgba(255,255,255,0)), color-stop(100%,rgba(255,255,255,.2))); /* Chrome,Safari4+ */
				background-image:-webkit-linear-gradient(top, rgba(255,255,255,0) 0%,rgba(255,255,255,.2) 100%); /* Chrome10+,Safari5.1+ */
				background-image:-o-linear-gradient(top, rgba(255,255,255,0) 0%,rgba(255,255,255,.2) 100%); /* Opera11.10+ */
				background-image:-ms-linear-gradient(top, rgba(255,255,255,0) 0%,rgba(255,255,255,.2) 100%); /* IE10+ */
				
				background:linear-gradient(top, rgba(255,255,255,0) 0%,rgba(255,255,255,.2) 100%); /* W3C */ 
			}
			
			
			.menu_btns.silver li:active a, .menu_btns.silver li:focus a {
				background-image:-webkit-gradient(linear, left bottom, left top, from(rgba(255,255,255,0.4)), to(rgba(255,255,255,0)));
				background-image:-moz-linear-gradient(top, rgba(255,255,255,0) 0%, rgba(255,255,255,.4) 100%); /* FF3.6+ */
				background-image:-webkit-gradient(linear, left top, left bottom, color-stop(0%,rgba(255,255,255,0)), color-stop(100%,rgba(255,255,255,.4))); /* Chrome,Safari4+ */
				background-image:-webkit-linear-gradient(top, rgba(255,255,255,0) 0%,rgba(255,255,255,.4) 100%); /* Chrome10+,Safari5.1+ */
				background-image:-o-linear-gradient(top, rgba(255,255,255,0) 0%,rgba(255,255,255,.4) 100%); /* Opera11.10+ */
				background-image:-ms-linear-gradient(top, rgba(255,255,255,0) 0%,rgba(255,255,255,.4) 100%); /* IE10+ */
				
				background:linear-gradient(top, rgba(255,255,255,0) 0%,rgba(255,255,255,.4) 100%); /* W3C */ 
				-webkit-box-shadow:inset 0 2px 5px rgba(0,0,0,.3); /* Saf3.0+, Chrome */
				   -moz-box-shadow:inset 0 2px 5px rgba(0,0,0,.3); /* FF3.5+ */
				        box-shadow:inset 0 2px 5px rgba(0,0,0,.3); /* Opera 10.5, IE 9.0 */
				
			}
	
	
	
	
			#right_panel .btn span, .btn_edit span{
				padding:0;
			}
			
			.btn_text span {
				padding:3px 7px !important;
			}
			
			
				
					






/*
	------------------------------------------------
	:: Tags
	------------------------------------------------
*/
    
    
.tag_annotation_wrapper .tag, .imagefilter .tag {
	 display:inline-block;
	 float:left;
	 margin:1px 3px;
	 position:relative;
	 
 }   
    
.tag .tag_inner{
    font-size: 1em;
	text-shadow: 0 1px 0 rgba(255,255,255,.8);
	display:inline-block;
	margin:2px 0;
	padding: 0 2em 0 .7em;
	line-height:1.5em;
    -webkit-border-radius: 30px;
	-moz-border-radius: 30px;
	border-radius: 30px;
	border:solid 1px hsl(205,40%,60%);
	background-image: -webkit-gradient(linear, left bottom, left top, from(hsl(205, 65%, 85%)), to(hsl(205, 60%, 90%)));
	
	background-image:-moz-linear-gradient(top, hsl(205,60%,90%) 0%, hsl(205,35%,85%) 100%); /* FF3.6+ */
	background-image:-webkit-gradient(linear, left top, left bottom, color-stop(0%,hsl(205,60%,90%)), color-stop(100%,hsl(205,35%,85%))); /* Chrome,Safari4+ */
	background-image:-webkit-linear-gradient(top, hsl(205,60%,90%) 0%,hsl(205,35%,85%) 100%); /* Chrome10+,Safari5.1+ */
	background-image:-o-linear-gradient(top, hsl(205,60%,90%) 0%,hsl(205,35%,85%) 100%); /* Opera11.10+ */
	background-image:-ms-linear-gradient(top, hsl(205,60%,90%) 0%,hsl(205,35%,85%) 100%); /* IE10+ */
	filter:progid:DXImageTransform.Microsoft.gradient( startColorstr='#5CACE6', endColorstr='#8DB9D9',GradientType=0 ); /* IE6-9 */
	background:linear-gradient(top, hsl(205,60%,90%) 0%,hsl(205,35%,85%) 100%); /* W3C */ 
	
	color:hsl(205,30%,35%);
	-webkit-box-shadow: inset 0 1px 0 rgba(255,255,255,.5);
	-moz-box-shadow: inset 0 1px 0 rgba(255,255,255,.5);
	box-shadow: inset 0 1px 0 rgba(255,255,255,.5);
}
    
.tag .tag_inner:hover {
	background-image: -webkit-gradient(linear, left bottom, left top, from(hsl(205, 70%, 75%)), to(hsl(205, 65%, 80%)));

	background:blue; /* Old browsers */
	background-image:-moz-linear-gradient(top, hsl(205,65%,80%) 0%, hsl(205,70%,75%) 100%); /* FF3.6+ */
	background-image:-webkit-gradient(linear, left top, left bottom, color-stop(0%,hsl(205,65%,80%)), color-stop(100%,hsl(205,70%,75%))); /* Chrome,Safari4+ */
	background-image:-webkit-linear-gradient(top, hsl(205,65%,80%) 0%,hsl(205,70%,75%) 100%); /* Chrome10+,Safari5.1+ */
	background-image:-o-linear-gradient(top, hsl(205,65%,80%) 0%,hsl(205,70%,75%) 100%); /* Opera11.10+ */
	background-image:-ms-linear-gradient(top, hsl(205,65%,80%) 0%,hsl(205,70%,75%) 100%); /* IE10+ */
	filter:progid:DXImageTransform.Microsoft.gradient( startColorstr='#4795CC', endColorstr='#3987BF',GradientType=0 ); /* IE6-9 */
	background:linear-gradient(top, hsl(205,65%,80%) 0%,hsl(205,70%,75%) 100%); /* W3C */ 
	
	text-decoration:none;
	text-shadow: 0 1px 0 rgba(255,255,255,.4);
	color:hsl(205,30%,30%);        
}


.removeTag {
	color: #000;
	cursor:pointer;
	font-weight:bold; 
	text-shadow: 0 1px 0 rgba(255,255,255,.7);
	display:inline-block;
	width:12px;
	height:12px;
	position:absolute;
	z-index:90;
	right:5px;
	top:5px;
	-webkit-border-radius:20px;
	-moz-border-radius:20px;
	border-radius:20px;
	text-align:center;
	margin-left:5px;
	overflow:hidden;
	display:block !important;
	background:url(../image/icon_tag_remove.png) center center no-repeat;
	text-indent:-99px;
}


.removeTag:hover {
	background-color:hsla(205,40%,60%,.7);
	color:hsl(210,20%,30%);
	text-shadow: 0 1px 0 rgba(255,255,255,.5);
}


#currentFilterTags {
	float: left;
	top: -1px;
	position: relative;
}





/*
	------------------------------------------------
	:: Form
	------------------------------------------------
*/

	
	.standard_form {
		overflow:visible;
	}
	
	    .standard_form .required label { 
	        color: #E3646F;
	    }
	    
		.standard_form label {
			padding-right: 5px;
			display:inline-block;
			color:hsl(210,10%,50%);
			font-size:1.2em;
			text-shadow: 0 1px 0 white;
			vertical-align: top;
			margin-top: 4px;
		}
		
		.standard_form input, .standard_form select, .standard_form textarea {
			display:inline-block;
			margin-bottom:5px;
		}

	.standard_form input[type=text],
	.standard_form input[type=password],
	.standard_form textarea {
		width:70%;
		border: solid 1px rgba(0,0,0,.2);
		border-top: solid 1px rgba(0,0,0,.3);
		-webkit-box-shadow: 0 1px 0 white, inset 0 1px 1px rgba(0,0,0,.1);
		-moz-box-shadow: 0 1px 0 white, inset 0 1px 1px rgba(0,0,0,.1);
		box-shadow: 0 1px 0 white, inset 0 1px 1px rgba(0,0,0,.1);
		-webkit-border-radius: 2px;
		-moz-border-radius: 2px;
		border-radius: 2px;
		padding:5px 2px;
		font-size:1.1em;
		color:#333;
		font-family:"HelveticaNeue-Medium", Helvetica, Arial, sans-serif
	}

	.standard_form input[type=text]:focus,
	.standard_form input[type=password]:focus,
	.standard_form input[type=text]:active,
	.standard_form input[type=password]:active {
		border:solid 1px hsl(210,20%,50%);
	}
	
			
			
			
	.standard_form input[type="submit"], .submit_btn {
		cursor: pointer;
		float:right;
		margin: 0;
		display:block;
		background-color:hsl(210,50%,60%);
		background-image: -webkit-gradient(linear, left bottom, left top, from(hsl(210,40%,60%)), to(hsl(210,40%,70%)));
		
		background:#fff; /* Old browsers */
		background-image:-moz-linear-gradient(top, hsl(210,40%,70%) 0%, hsl(210,40%,60%) 100%); /* FF3.6+ */
		background-image:-webkit-gradient(linear, left top, left bottom, color-stop(0%,hsl(210,40%,70%)), color-stop(100%,hsl(210,40%,60%))); /* Chrome,Safari4+ */
		background-image:-webkit-linear-gradient(top, hsl(210,40%,70%) 0%,hsl(210,40%,60%) 100%); /* Chrome10+,Safari5.1+ */
		background-image:-o-linear-gradient(top, hsl(210,40%,70%) 0%,hsl(210,40%,60%) 100%); /* Opera11.10+ */
		background-image:-ms-linear-gradient(top, hsl(210,40%,70%) 0%,hsl(210,40%,60%) 100%); /* IE10+ */
		filter:progid:DXImageTransform.Microsoft.gradient( startColorstr='#6B8FB3', endColorstr='#5C7A99',GradientType=0 ); /* IE6-9 */
		background:linear-gradient(top, hsl(210,40%,70%) 0%,hsl(210,40%,60%) 100%); /* W3C */ 
		
		
		border-top:solid 1px hsl(210,40%,50%);
		border-right:solid 1px hsl(210,40%,40%);
		border-left:solid 1px hsl(210,40%,40%);
		border-bottom:solid 1px hsl(210,40%,35%);
		-webkit-border-radius:3px;
		-moz-border-radius:3px;
		border-radius:3px;
		-webkit-box-shadow: inset 0 1px 0 rgba(255,255,255,.2), 0 1px 1px rgba(0,0,0,.3);
		-moz-box-shadow: inset 0 1px 0 rgba(255,255,255,.2), 0 1px 1px rgba(0,0,0,.3);
		box-shadow: inset 0 1px 0 rgba(255,255,255,.2), 0 1px 1px rgba(0,0,0,.3);
		padding:5px 20px;
		font-size:1.3em;
		font-weight:bold;
		color: hsl(210,70%,10%);
		text-shadow: 0 1px 0 rgba(255,255,255,.3);
		border-radius:3px;
		font-family: Helvetica, Arial;
	}

	a.submit_btn:visited {
		color: inherit;
	}

	.standard_form input[type="submit"]:disabled {
		opacity: 0.5;
	}
			
			
			
	.standard_form input[type="submit"]:hover {
		background-image: -webkit-gradient(linear, left bottom, left top, from(hsl(210,40%,60%)), to(hsl(210,40%,76%)));
		
		background-image:-moz-linear-gradient(top, hsl(210,40%,76%) 0%, hsl(210,40%,60%) 100%); /* FF3.6+ */
		background-image:-webkit-gradient(linear, left top, left bottom, color-stop(0%,hsl(210,40%,76%)), color-stop(100%,hsl(210,40%,60%))); /* Chrome,Safari4+ */
		background-image:-webkit-linear-gradient(top, hsl(210,40%,76%) 0%,hsl(210,40%,60%) 100%); /* Chrome10+,Safari5.1+ */
		background-image:-o-linear-gradient(top, hsl(210,40%,76%) 0%,hsl(210,40%,60%) 100%); /* Opera11.10+ */
		background-image:-ms-linear-gradient(top, hsl(210,40%,76%) 0%,hsl(210,40%,60%) 100%); /* IE10+ */
		filter:progid:DXImageTransform.Microsoft.gradient( startColorstr='#749BC2', endColorstr='#5C7A99',GradientType=0 ); /* IE6-9 */
		background:linear-gradient(top, hsl(210,40%,76%) 0%,hsl(210,40%,60%) 100%); /* W3C */ 
		
	}
			
	.standard_form input[type="submit"]:active,
	.standard_form input[type="submit"]:focus {
		background-image: -webkit-gradient(linear, left bottom, left top, from(hsl(210,40%,65%)), to(hsl(210,40%,60%)));
		

		background-image:-moz-linear-gradient(top, hsl(210,40%,60%) 0%, hsl(210,40%,65%) 100%); /* FF3.6+ */
		background-image:-webkit-gradient(linear, left top, left bottom, color-stop(0%,hsl(210,40%,60%)), color-stop(100%,hsl(210,40%,65%))); /* Chrome,Safari4+ */
		background-image:-webkit-linear-gradient(top, hsl(210,40%,60%) 0%,hsl(210,40%,65%) 100%); /* Chrome10+,Safari5.1+ */
		background-image:-o-linear-gradient(top, hsl(210,40%,60%) 0%,hsl(210,40%,65%) 100%); /* Opera11.10+ */
		background-image:-ms-linear-gradient(top, hsl(210,40%,60%) 0%,hsl(210,40%,65%) 100%); /* IE10+ */
		filter:progid:DXImageTransform.Microsoft.gradient( startColorstr='#5C7A99', endColorstr='#6385A6',GradientType=0 ); /* IE6-9 */
		background:linear-gradient(top, hsl(210,40%,60%) 0%,hsl(210,40%,65%) 100%); /* W3C */ 
		
		-webkit-box-shadow: none;
		-webkit-box-shadow:none    ; /* Saf3.0+, Chrome */
		   -moz-box-shadow:none    ; /* FF3.5+ */
		        box-shadow:none    ; /* Opera 10.5, IE 9.0 */
		
		border:solid 1px hsl(210,40%,40%);
	}
	
	







/*
	------------------------------------------------
	:: Datepicker
	------------------------------------------------
*/


	.ui-datepicker {
		border:hsl(210,10%,85%);
		background-color:hsl(210,10%,100%);
		-webkit-border-radius:3px; /* Saf3+, Chrome */
		   -moz-border-radius:3px; /* FF1+ */
		        border-radius:3px; /* Opera 10.5, IE 9 */ 
		-webkit-box-shadow:    0 4px 8px rgba(0,0,0,0.3), 0 0 1px rgba(0, 0, 0, 0.5); /* Saf3.0+, Chrome */
		   -moz-box-shadow:    0 4px 8px rgba(0,0,0,0.3), 0 0 1px rgba(0, 0, 0, 0.5); /* FF3.5+ */
		        box-shadow:    0 4px 8px rgba(0,0,0,0.3), 0 0 1px rgba(0, 0, 0, 0.5); /* Opera 10.5, IE 9.0 */
	}

	
		/* Header */

		.ui-datepicker-header {
			background-color:hsl(210,5%,90%);
			border-bottom:solid 1px hsl(210,10%,75%);
			background-image:-moz-linear-gradient(top, rgba(255,255,255,.3) 0%, rgba(255,255,255,0) 100%); /* FF3.6+ */
			background-image:-webkit-gradient(linear, left top, left bottom, color-stop(0%,rgba(255,255,255,.2)), color-stop(100%,rgba(255,255,255,0))); /* Chrome,Safari4+ */
			background-image:-webkit-linear-gradient(top, rgba(255,255,255,.3) 0%,rgba(255,255,255,0) 100%); /* Chrome10+,Safari5.1+ */
			background-image:-o-linear-gradient(top, rgba(255,255,255,.3) 0%,rgba(255,255,255,0) 100%); /* Opera11.10+ */
			background-image:-ms-linear-gradient(top, rgba(255,255,255,.3) 0%,rgba(255,255,255,0) 100%); /* IE10+ */
		
			background:linear-gradient(top, rgba(255,255,255,.3) 0%,rgba(255,255,255,0) 100%); /* W3C */ 
		}
		
			.ui-datepicker-prev, .ui-datepicker-next {
				border:solid 1px #c6c6c6;
				cursor:pointer;
				-webkit-box-shadow: 0 1px 0 rgba(255,255,255,0.4); /* Saf3.0+, Chrome */
				   -moz-box-shadow: 0 1px 0 rgba(255,255,255,0.4); /* FF3.5+ */
				        box-shadow: 0 1px 0 rgba(255,255,255,0.4); /* Opera 10.5, IE 9.0 */
				-webkit-border-radius:2px; /* Saf3+, Chrome */
				   -moz-border-radius:2px; /* FF1+ */
				        border-radius:2px; /* Opera 10.5, IE 9 */ 
			}
			
			.ui-datepicker-prev {
				background:url(../../webgateway/img/datepicker_prev.png) center 60% no-repeat;
			}
			
			.ui-datepicker-next {
				background:url(../../webgateway/img/datepicker_next.png) center 60% no-repeat;
				right: 0px;
			}
			
			
			.ui-datepicker-prev:hover, .ui-datepicker-next:hover {
				background-color:rgba(255,255,255,.1);
				top:0px;
				margin:0;
			}
			
		
	
		/* Days */
		
		.ui-datepicker thead{
			background-color:hsl(210,50%,85%);
			background-image:-moz-linear-gradient(top, rgba(255,255,255,.2) 0%, rgba(255,255,255,0) 100%); /* FF3.6+ */
			background-image:-webkit-gradient(linear, left top, left bottom, color-stop(0%,rgba(255,255,255,.2)), color-stop(100%,rgba(255,255,255,0))); /* Chrome,Safari4+ */
			background-image:-webkit-linear-gradient(top, rgba(255,255,255,.2) 0%,rgba(255,255,255,0) 100%); /* Chrome10+,Safari5.1+ */
			background-image:-o-linear-gradient(top, rgba(255,255,255,.2) 0%,rgba(255,255,255,0) 100%); /* Opera11.10+ */
			background-image:-ms-linear-gradient(top, rgba(255,255,255,.2) 0%,rgba(255,255,255,0) 100%); /* IE10+ */
			background:linear-gradient(top, rgba(255,255,255,.2) 0%,rgba(255,255,255,0) 100%); /* W3C */ 
		}
	
			.ui-datepicker thead th {
				padding:.5em 0 .3em;
				border-right:solid 1px hsl(210,50%,80%);
				border-bottom:solid 1px hsl(210,20%,80%);
				-webkit-box-shadow: 1px 0 0 rgba(255,255,255,0.3), inset 0 1px 0 rgba(255,255,255,.3); /* Saf3.0+, Chrome */
				   -moz-box-shadow: 1px 0 0 rgba(255,255,255,0.3), inset 0 1px 0 rgba(255,255,255,.3); /* FF3.5+ */
				        box-shadow: 1px 0 0 rgba(255,255,255,0.3), inset 0 1px 0 rgba(255,255,255,.3); /* Opera 10.5, IE 9.0 */
				color:hsl(210,30%,40%);
				text-shadow: 0 1px 0 rgba(255,255,255,.9);
			}



		/* Numbers */

			.ui-datepicker tbody td:hover a{
			    background-color:hsl(205,40%,50%);
				color:white;
			}
	
			.ui-datepicker tbody a{
				font-size:1.2em;
				border: 1px solid #CCCCCC;
			}

			.ui-datepicker .ui-state-highlight {
				background-color: #fef49c;
			}







/*
	------------------------------------------------
	:: Dialog/Modal Boxes
	------------------------------------------------
*/

html .ui-widget-overlay {
	background:rgba(255,255,255,.6);
	opacity: 1;
}

.ui-dialog {
	background-color: #f5f7f8;
	padding:0;
	-webkit-border-radius:6px; /* Saf3+, Chrome */
	   -moz-border-radius:6px; /* FF1+ */
	        border-radius:6px; /* Opera 10.5, IE 9 */ 
	border:solid 1px #666;
}


.ui-dialog-titlebar {
	padding:15px 10px !important;
	-webkit-border-top-left-radius:5px; /* Saf3+, Chrome */
	-webkit-border-top-right-radius:5px;
 	-moz-border-radius-topleft:5px; /* FF1+ */
	-moz-border-radius-topright:5px;
    border-top-left-radius:5px; /* Opera 10.5, IE 9 */ 
    border-top-right-radius:5px; 
	background-image:-moz-linear-gradient(top, hsl(210,10%,90%) 0%, hsl(210,10%,85%) 100%); /* FF3.6+ */
	background-image:-webkit-gradient(linear, left top, left bottom, color-stop(0%,hsl(210,10%,90%)), color-stop(100%,hsl(210,10%,85%))); /* Chrome,Safari4+ */
	background-image:-webkit-linear-gradient(top, hsl(210,10%,90%) 0%,hsl(210,10%,85%) 100%); /* Chrome10+,Safari5.1+ */
	background-image:-o-linear-gradient(top, hsl(210,10%,90%) 0%,hsl(210,10%,85%) 100%); /* Opera11.10+ */
	background-image:-ms-linear-gradient(top, hsl(210,10%,90%) 0%,hsl(210,10%,85%) 100%); /* IE10+ */
	filter:progid:DXImageTransform.Microsoft.gradient( startColorstr='#CFDAE6', endColorstr='#C3CED9',GradientType=0 ); /* IE6-9 */
	background:linear-gradient(top, hsl(210,10%,90%) 0%,hsl(210,10%,85%) 100%); /* W3C */ 
	-webkit-box-shadow:inset 0 1px 0 rgba(255,255,255,0.2); /* Saf3.0+, Chrome */
	   -moz-box-shadow:inset 0 1px 0 rgba(255,255,255,0.2); /* FF3.5+ */
	        box-shadow:inset 0 1px 0 rgba(255,255,255,0.2); /* Opera 10.5, IE 9.0 */
	
	margin-bottom:0px;
	position: relative;
	border-bottom:solid 1px hsl(210,10%,65%);
}

	.ui-dialog-title{
		font-size:1.3em;
		color:hsl(210,10%,40%) !important;
		text-shadow:0 1px 0 white;
	}

	

		.ui-dialog .ui-dialog-titlebar-close { 
			position: absolute; 
			right: .5em; 
			top: 50%;
			width: 19px;
			margin: -10px 0 0 0;
			height: 18px; 
			border:none;
			background:url(../../webgateway/img/close.png) center center no-repeat;
			/* https://github.com/ome/omero-web/pull/180#issuecomment-670499867 */
			color: transparent;
		}
	
		.ui-dialog .ui-dialog-titlebar-close:hover, .ui-dialog .ui-dialog-titlebar-close:focus {
			background:url(../../webgateway/img/close.png) center center no-repeat;
		}
		
		
		
	.ui-dialog h1{
		font-size:1.2em;
		font-weight:bold;
	}

	
		.ui-dialog .ui-dialog-titlebar-close span { 
			display: block; 
			background:none;
		}
		
		.ui-dialog select {
			font-size:1.2em;
			color:#333;
			font-family: 'HelveticaNeue-Medium', Helvetica;
		}
		
		
		.ui-icon-closethick {
			background:none;
		}
		
		
	



.ui-dialog .ui-dialog-buttonpane { 
	text-align: left; 
	border-width: 1px 0 0 0; 
	background-image: none;
	background-color:hsl(210,5%,95%);
	border-top:solid 1px hsl(210,5%,75%);
}

	.ui-dialog .ui-dialog-buttonpane .ui-dialog-buttonset { 
		float: right;
	}

		.ui-dialog .ui-dialog-buttonpane button { 
			cursor: pointer; 
			background:hsl(210,8%,80%); /* Old browsers */
			background-image:-moz-linear-gradient(top, rgba(255,255,255,.2) 0%, rgba(255,255,255,0) 100%); /* FF3.6+ */
			background-image:-webkit-gradient(linear, left top, left bottom, color-stop(0%,rgba(255,255,255,.2)), color-stop(100%,rgba(255,255,255,0))); /* Chrome,Safari4+ */
			background-image:-webkit-linear-gradient(top, rgba(255,255,255,.2) 0%,rgba(255,255,255,0) 100%); /* Chrome10+,Safari5.1+ */
			background-image:-o-linear-gradient(top, rgba(255,255,255,.2) 0%,rgba(255,255,255,0) 100%); /* Opera11.10+ */
			background-image:-ms-linear-gradient(top, rgba(255,255,255,.2) 0%,rgba(255,255,255,0) 100%); /* IE10+ */
		
			background:linear-gradient(top, rgba(255,255,255,.1) 0%,rgba(255,255,255,0) 100%); /* W3C */ 
			-webkit-box-shadow:inset 0 1px 0 rgba(255,255,255,0.1); /* Saf3.0+, Chrome */
			   -moz-box-shadow:inset 0 1px 0 rgba(255,255,255,0.1); /* FF3.5+ */
			        box-shadow:inset 0 1px 0 rgba(255,255,255,0.1); /* Opera 10.5, IE 9.0 */
			color:#333;
			height:30px;
			text-shadow:0 1px 0 rgba(255, 255, 255, 0.7);
			-webkit-border-radius:3px; /* Saf3+, Chrome */
			   -moz-border-radius:3px; /* FF1+ */
			        border-radius:3px; /* Opera 10.5, IE 9 */ 
			border:solid 1px hsl(210,8%,70%); 
		}
		
		.ui-dialog .ui-dialog-buttonpane button:hover { 
			background:hsl(210,8%,85%);
		}
		
		.ui-dialog .ui-dialog-buttonpane button:active, .ui-dialog .ui-dialog-buttonpane button:focus { 
			background:hsl(210,8%,80%); /* Old browsers */
			background-image:-moz-linear-gradient(top, rgba(255,255,255,0) 0%, rgba(255,255,255,.2) 100%); /* FF3.6+ */
			background-image:-webkit-gradient(linear, left top, left bottom, color-stop(0%,rgba(255,255,255,0)), color-stop(100%,rgba(255,255,255,.2))); /* Chrome,Safari4+ */
			background-image:-webkit-linear-gradient(top, rgba(255,255,255,0) 0%,rgba(255,255,255,.2) 100%); /* Chrome10+,Safari5.1+ */
			background-image:-o-linear-gradient(top, rgba(255,255,255,0) 0%,rgba(255,255,255,.2) 100%); /* Opera11.10+ */
			background-image:-ms-linear-gradient(top, rgba(255,255,255,0) 0%,rgba(255,255,255,.2) 100%); /* IE10+ */

			background:linear-gradient(top, rgba(255,255,255,0) 0%,rgba(255,255,255,.2) 100%); /* W3C */ 
		}
		


	.new_pds_owner_icon {
		width: 16px;
		height: 16px;
	}






/*
	------------------------------------------------
	:: Search
	------------------------------------------------
*/

 


	#search input[type=text], .filtersearch input[type=text], #imagesPerRow {
		-webkit-border-radius:50px;
		-moz-border-radius:50px;
		border-radius:50px;
		border:solid 1px hsl(215,15%,30%);
		border-top:solid 1px hsl(215,15%,18%);
		border-color: #727F8C #9199A0 #9199A0;
		padding: .2em .5em;
		font-size:1.2em;
		color:#333;
		-webkit-box-shadow: 0 1px 0 rgba(255,255,255,.2), inset 0 1px 1px rgba(0,0,0,.2);
		-moz-box-shadow: 0 1px 0 rgba(255,255,255,.2), inset 0 1px 1px rgba(0,0,0,.2);
		box-shadow: 0 1px 0 rgba(255,255,255,.15), inset 0 1px 2px rgba(0,0,0,.3);
		right: 0;
	}

	#search input[type=submit], .filtersearch input[type=submit]{
		text-indent: -9999px;
		position:absolute;
		top:50%;
		margin-top:-10px;
		right:7px;
		background: url(../image/search.png) center center no-repeat;
		width:20px;
		height:20px;
		border:none !important;
		display:block;
		opacity:.2;
		-webkit-transition:   opacity .2s linear;		
		   -moz-transition:   opacity .2s linear;
		     -o-transition:   opacity .2s linear;
		        transition:   opacity .2s linear; 
	}
	
	#search input[type=submit]:hover, .filtersearch input[type=submit]:hover {
		opacity:.6;
		cursor:pointer;
		-webkit-transition:opacity .2s linear;
		
		-webkit-transition:   opacity .2s linear;		
		   -moz-transition:   opacity .2s linear;
		     -o-transition:   opacity .2s linear;
		        transition:   opacity .2s linear; 
		
	}
	
	
	
	/* Filter Search */
	
    .filtersearch{
        position: relative;
        margin:4px;
        width: calc(100% - 100px);
        height:22px;
    }

    .searchresult_filter {
        position: absolute;
        top: 1px;
        left: 5px;
        width: 180px;
    }

    .searchresult_filter input {
    	box-sizing: border-box;
    	width: 180px;
    }
  
        .filtersearch input {
            border:solid 1px rgba(0,0,0,.6);
            border-top:solid 1px rgba(0,0,0,.6);
            position:absolute;
        }

		.filtersearch select {
			margin-top: 2px;
			float: left;
			width: 100px;
			margin-right: 4px;
		}

        .filtersearch label {
            position:absolute;
            z-index:50;
            font-size:1.3em;
            font-weight:lighter;
            top:5px;
            left:8px;
        }
		
		.filtersearch .loading {
			position:absolute;
			left: 110%;
			top: 6px;
		}
	
	/* same as .filtersearch label for top search field */
	.inline_label {
	    position:absolute;
        z-index:50;
        font-size:1.3em;
        font-weight:lighter;
        top:5px;
        left:8px;
	}
	

	.imagefilter {
		float:left;
		display:none;
	}

	#filterrating .removefilter {
		visibility: hidden;
	}

	#filterrating:hover .removefilter {
		display: inline-block;
		visibility: visible;
	}
	.removefilter:hover {
		cursor: pointer;
		color: blue;
	}

	#filtername {
		position: relative;
		width: 180px;
		height:30px;
		top: -1px;
		margin: 0 2px 0 7px;
	}

	#filtername input {
		width: 90%;
	}

	#filterrating {
		margin: 2px 2px 2px 7px;
	}

	/* Filter by Map Annotation - auto-complete */
	ul.ui-autocomplete{
		background: #ffffff;
		border:solid 1px #D4D6D8;
		max-height: 400px;
		overflow-y: scroll;
	}

	.ui-menu-item a.ui-state-focus{
		background: #D4D6D8;
	}

	.ui-menu-item a{
		background:#ffffff;
		font-size: 10px;
		width: 135px;
	}














/* 
	----------------------------------------

	:: Context Box - Dark
	
	----------------------------------------  
*/





	.contextbox_dark {
		border: solid 1px red;
		width: 250px;
		padding: 10px;
		border: solid 1px black;
		-webkit-box-shadow: inset 0 1px 0 rgba(255,255,255,.1);
		-moz-box-shadow: inset 0 1px 0 rgba(255,255,255,.1);
		box-shadow: inset 0 1px 0 rgba(255,255,255,.1);
		-webkit-border-radius: 4px;
		-moz-border-radius: 4px;
		border-radius: 4px;
		background-color: hsl(210,0%,15%);
		font-size: 1.2em;
	}

		.contextbox_dark::after {
			background: url('../../webgateway/img/contextbox_arrowup.png') no-repeat;
		}

		.contextbox_dark h1 {
			color: white;
			text-shadow: 0 -1px 1px black;
		}

		.contextbox_dark .contextbox_inner {
			border:  solid 1px black;
			-webkit-box-shadow: 0 1px 0 rgba(255,255,255,.1);
			-moz-box-shadow: 0 1px 0 rgba(255,255,255,.1);
			box-shadow: 0 1px 0 rgba(255,255,255,.1);
		}


	
					.contextbox_dark li a {
						padding: 1em;
						font-weight: lighter;
						display: block;
						font-family: 'Helveticaneue-Medium', Helvetica, Arial, sans-serif;
						color: hsl(0,0%,20%);
						text-shadow: 0 1px 0 white;
					}


