{% extends 'webgateway/base/base_header.html' %}

{% comment %}
<!--
  Copyright (C) 2011-2014 University of Dundee & Open Microscopy Environment.
  All rights reserved.

  This program is free software: you can redistribute it and/or modify
  it under the terms of the GNU Affero General Public License as
  published by the Free Software Foundation, either version 3 of the
  License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU Affero General Public License for more details.

  You should have received a copy of the GNU Affero General Public License
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
-->
{% endcomment %}

{% block link %}
    {{ block.super }}
    <link rel="stylesheet" href="{% static "webgateway/css/ome.toolbar.css"|add:url_suffix %}" type="text/css" media="screen"/>
{% endblock %}

{% block script %}
    {{ block.super }}
    <!-- Include our current version of jQuery-UI and an ome utility script used by many pages -->
    {% include "webgateway/base/includes/jquery-ui.html" %}
    {% include "webgateway/base/includes/script_src_popup.html" %}

    <!-- Turn touch events into drag events for jquery-ui -->
    <script type="text/javascript" src="{% static "3rdparty/jquery.ui.touch-punch-0.2.3.min.js" %}"></script>

    <!-- Allow webclient to be 'added to home-screen' as a full-screen app on iOS -->
    <meta name="apple-mobile-web-app-capable" content="yes">
{% endblock %}
