{% extends "base_error.html" %}
{% load i18n %}

{% block content %}
    <div class="error"><h1>{% trans "Page not found." %} <em>(404)</em></h1>
    <p>{% trans "The requested object or URL was not found on this server. The link you followed is either outdated, inaccurate, or the server has been instructed not to let you have it." %}</p></div>
    
{% endblock %}