{% comment %}
<!--
  Copyright (C) 2013 University of Dundee & Open Microscopy Environment.
  All rights reserved.

  This program is free software: you can redistribute it and/or modify
  it under the terms of the GNU Affero General Public License as
  published by the Free Software Foundation, either version 3 of the
  License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU Affero General Public License for more details.

  You should have received a copy of the GNU Affero General Public License
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
-->
{% endcomment %}


<div class="toolbar_dropdown">
    <button class="btn silver btn_figscripts" title="Publishing Options">
        <span></span>
    </button>
    <ul id="figScriptList" class="dropdown">
        {% for script in figScripts %}
        <li {% if not script.enabled %}class="disabled"{% endif %}
            title="{{ script.tooltip }}">
            <a href="{% url 'figure_script' script.id %}">
                {{ script.name }}...
            </a>
        </li>
        {% endfor %}
    </ul>
</div>