{% comment %}
<!--
  Copyright (C) 2011-2013 University of Dundee & Open Microscopy Environment.
  All rights reserved.

  This program is free software: you can redistribute it and/or modify
  it under the terms of the GNU Affero General Public License as
  published by the Free Software Foundation, either version 3 of the
  License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU Affero General Public License for more details.

  You should have received a copy of the GNU Affero General Public License
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
-->
{% endcomment %}

<!-- allow apps to include custom html -->
{% block right_panel_title %}
{% endblock %}

{% if obj.canEdit and not manager.well %}
    <div class="data_heading" id="{{ manager.obj_type }}name-{{ manager.obj_id }}">
        <div>
            <h1>
                <span id="{{ manager.obj_type }}name-{{ manager.obj_id }}-name">
                    {{ nameText|escape }}
                </span>
            </h1>
            <button class="btn silver btn_edit" alt="e" title="Edit the name">
                <span></span>
            </button>
        </div>
    </div>
{% else %}
    <div class="data_heading">
      <h1>{{ nameText|escape }}</h1>
    </div>
{% endif %}

<div style="position:relative">
    {% if inPlace %}
      <img title="This file in an in-place import. The data might not be located within the OMERO data directory."
        style="position: absolute; top: 0; right: 3px"
        src="{% static 'webclient/image/inPlace_16.png' %}"/>
    {% endif %}
    <table style="width: 50%">
        <tr class="data_heading_id">
            {% if manager.obj_type == "acquisition" %}
              <th>Run ID:</th>
            {% else %}
              <th>{{ manager.obj_type|title }} ID:</th>
            {% endif %}
            <td><strong>{{ manager.obj_id }}</strong></td>
        </tr>
        <tr>
            <th>Owner:</th>
            <td id='owner_fullname'>{{ obj.getOwner.getFullName }}</td>
        </tr>
    </table>

    {% if not manager.tag %}
    <select id="annotationFilter" title="Filter annotations by user" data-userId="{{ ome.user.id }}"
            style="position:absolute; right:0; bottom:3px; width:80px">
        <option value="all">Show all</option>
        <option value="me">Show added by me</option>
        <option value="others">Show added by others</option>
    </select>
    {% endif %}

</div>
