/*
 * Copyright (C) 2012 University of Dundee & Open Microscopy Environment.
 * All rights reserved.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */
 

 

html {
    height: 100%;
}

html body {
	font-size: 62.5%;
}

body {
    color: #555555;
	-webkit-font-smoothing: antialiased; /* Deliciously smooths text for webkit browsers */
    font-family: 'HelveticaNeue-Medium', Helvetica, Arial, Verdana, Lucida, sans-serif;
    height: 100%;
    padding: 0px;
    margin: 0px;
    position: relative;
	background:hsl(215,9%,88%);
	-webkit-transition: color .2s linear;
}

a:hover, a, a:visited {
    color: #1B7BC7;
	color: hsl(207,60%,40%);
	-webkit-transition: all .2s linear;
    -webkit-transition: left 0s linear;
    text-decoration: none;
}


h1 {
    font-size: 15px;
    text-align: left;
    margin: 0;
    padding: 10px 0;
}

	h1.page_title {
		border-bottom:solid 1px rgba(0,0,0,0.05);
		margin-bottom:20px;
	}

h2{
    font-size:1.1em;
    line-height:1.6em;
    text-shadow: 0 1px 0 rgba(255,255,255,1);
    text-transform: uppercase;
    color:hsl(210,7%,60%);
    font-weight:bold;
	margin-bottom:6px;
}


p, dl {
	font-size:1.2em;
	line-height:1.4em;
	margin-bottom:15px;
}

h1 p {
	margin-bottom:0;
}

dl {
	overflow:hidden;
}

dt, dd {
	display:inline-block;
}

dt {
	width:30%;
}

dd {
	width:69%;
}

strong {
	font-weight:bold;
}


ul.errorlist {
    list-style: none;
	margin:0;
    color: #e3646f;
}


label {
    font-weight: bold;
}

.clear {
    clear: both;
    width: 0px;
    margin: 0px;
    padding: 0px;
}


.form_error {
	background-color: hsl(0,30%,80%);
}

.error, .form_error {
	color:#E3646F;
	line-height:1.3em;
	padding:5px;
	-webkit-border-radius:2px;
	-webkit-border-radius:2px; /* Saf3+, Chrome */
	   -moz-border-radius:2px; /* FF1+ */
	        border-radius:2px; /* Opera 10.5, IE 9 */ 
	font-size:1.1em;				
}


.disabled {
    background: #dcdcdc;
    color: #777777;
}

.toolbar_noborder {
    height:19px;
    padding:5px; 
}
.align_left {
    float:left;
}
.align_right {
    float:right;
    text-align: right;
}
.align_center {
    text-align: center;
}




/* hidden div to specify which parent tab is 'current' */
#parent_id {
    display: none;
}

/* used by the dialog in popup.js 
.ui-dialog-titlebar { background: gray; color: white } */

.absolute_fill {
    top: 0;
    bottom: 0;
    left: 0;
    right: 0;
    position: absolute;
    overflow: auto;
}