{% extends "webclient/base/base.html" %}
{% load i18n %}


{% comment %}
<!--
  Copyright (C) 2011 University of Dundee & Open Microscopy Environment.
  All rights reserved.

  This program is free software: you can redistribute it and/or modify
  it under the terms of the GNU Affero General Public License as
  published by the Free Software Foundation, either version 3 of the
  License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU Affero General Public License for more details.

  You should have received a copy of the GNU Affero General Public License
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
-->
{% endcomment %}

{% block link %}
    {{ block.super }}
{% endblock %}

{% block script %}

    <!--
        This template is no-longer used by omero-web
        Since it will be removed soon, we need to be sure that any users are warned:
    -->
    <script>alert("WARNING: Django template webclient/index/index.html has been deprecated")</script>

    {{ block.super }}
    
    <script type="text/javascript">
        $(document).ready(function() 
            {
                $("div#import_details").html('<p>Loading imported images... please wait <img src="{% static "webgateway/img/spinner.gif" %}"/></p>');
                $("div#import_details").load("{% url 'index_last_imports' %}");

                $("div#tag_details").html('<p>Loading tag cloud... please wait <img src="{% static "webgateway/img/spinner.gif" %}"/></p>');
                $("div#tag_details").load("{% url 'index_tag_cloud' %}");

                $("div#most_recent_details").html('<h1>Most recents:</h1><p>Loading data... please wait <img src ="{% static "webgateway/img/spinner.gif" %}"/></p>');
                $("div#most_recent_details").load("{% url 'index_most_recent' %}");
        })
    </script>
    
{% endblock %}

{% block center %}
    <div id="import_details"></div>
    
{% endblock %}

{% block right %}
    
    <div id="metadata_details">
        <div id="tag_details"></div>
        <div id="most_recent_details"></div>
    </div>
    
{% endblock %}
