{% comment %}
<!--
  Copyright (C) 2011 University of Dundee & Open Microscopy Environment.
  All rights reserved.

  This program is free software: you can redistribute it and/or modify
  it under the terms of the GNU Affero General Public License as
  published by the Free Software Foundation, either version 3 of the
  License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU Affero General Public License for more details.

  You should have received a copy of the GNU Affero General Public License
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
-->

{% endcomment %}


<form id="search" action="{% url 'load_template' 'search' %}" title="Search OMERO">

    <div id="top_search_field">
        <label class="inline_label" for="id_search_query">Search:</label>
        {{ global_search_form.search_query }}
        <input type="submit" value="Go" />
    </div>
    
</form>