{% extends "webadmin/admin_base.html" %}
{% load i18n %}

{% comment %}
<!--
  Copyright (C) 2011 University of Dundee & Open Microscopy Environment.
  All rights reserved.

  This program is free software: you can redistribute it and/or modify
  it under the terms of the GNU Affero General Public License as
  published by the Free Software Foundation, either version 3 of the
  License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU Affero General Public License for more details.

  You should have received a copy of the GNU Affero General Public License
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
-->
{% endcomment %}

{% block title %}{% trans "OMERO Users" %}{% endblock %}

{% block center_details %}
{{ block.super }}

  <div id="announce_content">
      <div class="one_column_content">
        <h1>{% trans "Email Announcement Unavailable" %}</h1>
        <p> This is because there are not sufficient settings configured to facilitate sending emails. Please configure OMERO web according to the documentation and restart the web server.</p>
      </div>
  </div>

{% endblock %}
