/**
 * jquery-plugin-slider - style definitions
 * 
 * Copyright (c) 2007, 2008, 2009 Glencoe Software, Inc. All rights reserved.
 * 
 * This software is distributed under the terms described by the LICENCE file
 * you can find at the root of the distribution bundle, which states you are
 * free to use it only for non commercial purposes.
 * If the file is missing please request a copy by contacting
 * jason@glencoesoftware.com.
 *
 * Author: Carlos Neves <carlos(at)glencoesoftware.com>
 */

/***********************************/
/* Horizontal Slider generic rules */

.hslider .slider-line { 
  cursor: pointer;
  font-size: 1px;
  border: 1px solid;
  position: absolute;
  display: block;
  left: 50px;
  right: 50px;
  height: 100%;
  top: 3px;

  /** HACK ALERT: you need to add this to your stylesheet to make it work in IE!! **/
  /*  height: expression(document.getElementById('__slider__id__').clientHeight - 30);  */
}

.hslider .slider-btn-down, .hslider .slider-btn-playdown { 
  display: block;
  cursor: pointer;
  position: absolute;
  right: 25px;
  text-align: right;
  width: 18px;
  height: 18px;
  top: 1px;
  background: url('../img/blue_arrow_right.gif') no-repeat center;
  border: solid #ddd 1px;
}

.hslider .slider-btn-playdown {
  right: 0px;
  background: url('../img/blue_play_right.gif') no-repeat center;
}

.hslider .slider-btn-up, .hslider .slider-btn-playup { 
  display: block;
  cursor: pointer;
  position: absolute;
  left: 25px;
  text-align: left;
  width: 18px;
  height: 18px;
  top: 1px;
  background: url('../img/blue_arrow_left.gif') no-repeat center;
  border: solid #ddd 1px;
}

.hslider .slider-btn-playup {
  left: 0px;
  background: url('../img/blue_play_left.gif') no-repeat center;
}

.hslider .onplay {
  background: url('../img/blue_square.gif') no-repeat center;
}

/*********************************/
/* Vertical Slider generic rules */

.vslider .slider-line { 
  cursor: pointer;
  font-size: 1px;
  border: 1px solid;
  position: absolute;
  display: block;
  top: 50px;
  bottom: 50px;
  width: 100%;
  right: 3px;
  /** HACK ALERT: you need to add this to your stylesheet to make it work in IE!! **/
  /*  height: expression(document.getElementById('__slider__id__').clientHeight - 30);  */
}

.vslider .slider-btn-down, .vslider .slider-btn-playdown { 
  position: absolute;
  cursor: pointer;
  display: block;
  bottom: 25px;
  right: 0px;
  width: 18px;
  height: 18px;
  text-align: center;
  background: url('../img/blue_arrow_down.gif') no-repeat center;
  border: solid #ddd 1px;
}

.vslider .slider-btn-playdown {
  bottom: 0px;
  background: url('../img/blue_play_down.gif') no-repeat center;
}

.vslider .slider-btn-up, .vslider .slider-btn-playup { 
  position: absolute;
  cursor: pointer;
  display: block;
  top: 25px;
  width: 18px;
  height: 18px;
  right: 0px;
  text-align: center;
  background: url('../img/blue_arrow_up.gif') no-repeat center;
  border: solid #ddd 1px;
}

.vslider .slider-btn-playup {
  top: 0px;
  background: url('../img/blue_play_up.gif') no-repeat center;
}

.vslider .onplay {
  background: url('../img/blue_square.gif') no-repeat center;
}

/***********/
/* Generic */

.slider-handle { 
  position: absolute;
  display: block;
  border: 1px solid;
  width: 100%;
  height: 100%;
  font-size: 1px;
}

.slider-handle.disabled { 
  background: #CCC;
}
